@@ -2,22 +2,22 @@ use core::str::FromStr;
 
 use crate::heapless::String;
 
-pub trait Autocomplete<const ITEM_LEN: usize> {
-    fn suggest(&self, prefix: &str) -> Option<String<ITEM_LEN>>;
+pub trait Autocomplete<const COMMAND_LEN: usize> {
+    fn suggest(&self, prefix: &str) -> Option<String<COMMAND_LEN>>;
 }
 
 pub struct NoAutocomplete;
 
-impl<const ITEM_LEN: usize> Autocomplete<ITEM_LEN> for NoAutocomplete {
-    fn suggest(&self, _prefix: &str) -> Option<String<ITEM_LEN>> {
+impl<const COMMAND_LEN: usize> Autocomplete<COMMAND_LEN> for NoAutocomplete {
+    fn suggest(&self, _prefix: &str) -> Option<String<COMMAND_LEN>> {
         None
     }
 }
 
 pub struct StaticAutocomplete<const N: usize>(pub [&'static str; N]);
 
-impl<const ITEM_LEN: usize, const N: usize> Autocomplete<ITEM_LEN> for StaticAutocomplete<N> {
-    fn suggest(&self, prefix: &str) -> Option<String<ITEM_LEN>> {
+impl<const COMMAND_LEN: usize, const N: usize> Autocomplete<COMMAND_LEN> for StaticAutocomplete<N> {
+    fn suggest(&self, prefix: &str) -> Option<String<COMMAND_LEN>> {
         if prefix.len() == 0 {
             return None;
         }
